from zuele import Tokenizer

tok = Tokenizer()
print(list(tok.cut(
    "立方数科股份有限公司2021 年年度报告摘要 " +
    "连锁品牌实体门店柜共 814 家（自营 384 家，加盟 430 家），分布在全国各大中城市主要商圈及" +
    "百货商店。" +
    "商业物业租赁经营：公司目前自有物业 16.70 万平方米，其中位于上海市淮海中路沿线及周" +
    "边地区有 9.50 万平方米左右，主要以商铺和写字楼为主；其余物业分布在浦东北蔡、闵行莘庄等" +
    "地，主要以厂房为主，上述物业约有 1.70 万平方米为企业经营自用，其余均对外招商出租经营。" +
    "酒店餐饮旅游：公司的餐饮旅游业务主要由下属上海益民酒店管理有限公司经营，上海益民" +
    "酒店管理有限公司旗下的金辰大酒店为按照较高标准打造的特色精品酒店，拥有各类客房 103 间，" +
    "并提供餐饮等服务。")))
